@@ -67,9 +67,9 @@ class TableParserRERratp(Extractor, HTMLParser.HTMLParser):
       if self.tagHeurePassageB:
          heure = data.strip()
          voie=''
-         res = re.search("(.+?)\s+[vV]\.?(?:oie)?\s?(\d+)", heure)
+         res = re.search("(.+?)\s+(?:D.part)?\s*[vV]\.?(?:oie)?\s?(\d+)", heure)
          if res:
-            heure = res.group(1).strip()
+            heure = res.group(1).strip().replace(':', 'h')
             voie = res.group(2).strip()
 
          self.currentRide.setVoie(voie)
