@@ -100,17 +100,18 @@ class RidesConfig:
       for k in sorted(self.rides.keys()):
          ride = self.rides[k]
          key="Ride%d"%iride
-         f.write('[%s]\n'%key)
-         f.write('tec=%s\n'%ride.tec)
-         f.write('Ligne=%s\n'%ride.ligne)
-         f.write('depart=%s\n'%ride.depart.encode('utf-8'))
-         f.write('arrivee=%s\n'%ride.arrivee.encode('utf-8'))
-         f.write('codeDepart=%s\n'%ride.codeDepart)
-         f.write('codeArrivee=%s\n'%ride.codeArrivee)
-         f.write('exploitant=%s\n'%ride.exploitant)
+         f.write('[%s]\n'%key.strip())
+         f.write('tec=%s\n'%ride.tec.strip())
+         f.write('Ligne=%s\n'%ride.ligne.strip())
+         f.write('depart=%s\n'%ride.depart.encode('utf-8').strip())
+         f.write('arrivee=%s\n'%ride.arrivee.encode('utf-8').strip())
+         f.write('codeDepart=%s\n'%ride.codeDepart.strip())
+         f.write('codeArrivee=%s\n'%ride.codeArrivee.strip())
+         f.write('exploitant=%s\n'%ride.exploitant.strip())
          if ride.direction:
-            f.write('direction=%s\n'%ride.direction)
+            f.write('direction=%s\n'%ride.direction.strip())
 
+         f.write('\n')
 #         t.add_section(key)
 #         t.set(key, 'TEC', ride.tec)
 #         t.set(key, 'Ligne', ride.ligne)
