@@ -140,7 +140,7 @@ class RideView(QtGui.QWidget):
       self.layout.addLayout( layoutTitle, 0, 1, 1, 3, Qt.AlignLeft|Qt.AlignVCenter )
 
    def Remove(self):
-      reply = QtGui.QMessageBox.question(None, 'Message',
+      reply = QtGui.QMessageBox.question(None, 'Attention',
              "Supprimer le trajet '%s'?"%self.model.getTitle(),
              QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
 
@@ -172,6 +172,7 @@ class RideView(QtGui.QWidget):
       height=48
       self.font.setPointSize(14)
       self.progressIcon.hide()
+      self.HideInfo()
 
       # Rides
       for line in self.model.getRides():
