@@ -23,11 +23,23 @@ class SettingsDlg(QtGui.QDialog ):
       labelnb = QtGui.QLabel('Nombre de trains par trajet')
       self.editnb = QtGui.QLineEdit()
       self.editnb.setText('%d'%self.conf.nbTrains())
-      hLayout.addWidget(labelnb) 
+      hLayout.addWidget(labelnb)
       hLayout.addWidget(self.editnb)
 
+      hLayout2 = QtGui.QHBoxLayout()
+      labelra = QtGui.QLabel(u'Rafraîchissement auto')
+      self.refresh = QtGui.QComboBox()
+      rlist = QtCore.QStringList()
+      rlist << '15 s' << '30 s' << '1 min' << '5 min'
+      self.refresh.addItems(rlist)
+      idx = rlist.indexOf(self.conf.refreshRate())
+      self.refresh.setCurrentIndex(idx)
+      hLayout2.addWidget(labelra)
+      hLayout2.addWidget(self.refresh)
+
       vbox = QtGui.QVBoxLayout()
       vbox.addLayout(hLayout)
+      vbox.addLayout(hLayout2)
 
       hLayout3 = QtGui.QHBoxLayout()
       buttons = QtGui.QDialogButtonBox()
@@ -41,8 +53,9 @@ class SettingsDlg(QtGui.QDialog ):
       self.setLayout(vbox)
 
    def OnOK(self):
-      nb = self.editnb.text()
-      self.conf.WriteConfig(nb)
+      self.conf.SetNbTrains( self.editnb.text() )
+      self.conf.SetRefreshRate( self.refresh.currentText() )
+      self.conf.WriteConfig()
       self.accept()
 
    def OnCancel(self):
